spannertools.make_colored_text_spanner_with_nibs
================================================

.. autofunction:: abjad.tools.spannertools.make_colored_text_spanner_with_nibs.make_colored_text_spanner_with_nibs
